==> mono-2.4.3.tar.bz2: mono-2.4.3/mcs/class/System.ServiceModel/System.ServiceModel.Dispatcher/ChannelDispatcherCollection.cs <==
//
// ChannelDispatcherCollection.cs
//
// Author:
//	Atsushi Enomoto <atsushi@ximian.com>
//
// Copyright (C) 2005 Novell, Inc.  http://www.novell.com
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;

namespace System.ServiceModel.Dispatcher
{
	public class ChannelDispatcherCollection
		: SynchronizedCollection<ChannelDispatcherBase>
	{
		private ServiceHostBase _service;

		internal ChannelDispatcherCollection (ServiceHostBase service)
		{
			_service = service;
		}

		internal ChannelDispatcherCollection (
			ChannelDispatcherBase [] listeners)
			: base (listeners)
		{
		}

		[MonoTODO ("What to do here?")]
		protected override void ClearItems ()
		{			
			ChannelDispatcherBase[] channels = this.InnerList.ToArray ();
			base.ClearItems ();
			foreach (ChannelDispatcherBase c in channels)
				c.Detach (_service);
		}

		internal List<ChannelDispatcherBase> InnerList {
			get { return Items; }
		}

		[MonoTODO ("What to do here?")]
		protected override void InsertItem (int index, ChannelDispatcherBase item)
		{
			item.Attach (_service);
			base.InsertItem (index, item);			
		}

		[MonoTODO ("What to do here?")]
		protected override void RemoveItem (int index)
		{
			ChannelDispatcherBase removed = this [index];
			base.RemoveItem (index);
			removed.Detach (_service);
			
		}

		[MonoTODO ("What to do here?")]
		protected override void SetItem (int index, ChannelDispatcherBase item)
		{
			item.Attach (_service);
			base.SetItem (index, item);			
		}		
	}
}

==> mono-4.4.2.11.tar.bz2: mono-4.4.2/mcs/class/System.ServiceModel/System.ServiceModel.Dispatcher/ChannelDispatcherCollection.cs <==
//
// ChannelDispatcherCollection.cs
//
// Author:
//	Atsushi Enomoto <atsushi@ximian.com>
//
// Copyright (C) 2005 Novell, Inc.  http://www.novell.com
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;

namespace System.ServiceModel.Dispatcher
{
	public class ChannelDispatcherCollection
		: SynchronizedCollection<ChannelDispatcherBase>
	{
		private ServiceHostBase _service;

		internal ChannelDispatcherCollection (ServiceHostBase service)
		{
			_service = service;
		}

		protected override void ClearItems ()
		{			
			foreach (ChannelDispatcherBase c in this)
				c.Detach (_service);
			base.ClearItems ();
		}

		protected override void InsertItem (int index, ChannelDispatcherBase item)
		{
			item.Attach (_service);
			base.InsertItem (index, item);			
		}

		protected override void RemoveItem (int index)
		{
			ChannelDispatcherBase removed = this [index];
			base.RemoveItem (index);
			removed.Detach (_service);
			
		}

		protected override void SetItem (int index, ChannelDispatcherBase item)
		{
			item.Attach (_service);
			base.SetItem (index, item);			
		}		
	}
}
